CREATE TABLE IF NOT EXISTS zip_new (zip_id INTEGER PRIMARY KEY, string TEXT);
DELETE FROM zip_new;
INSERT INTO zip_new SELECT null, string FROM zip;

.output 'bliss_dump.sql'

.mode tabs
SELECT 'BEGIN;';
SELECT 'TRUNCATE config;';
SELECT 'TRUNCATE acctypes;';
SELECT 'TRUNCATE zip;';
SELECT 'TRUNCATE nas;';
SELECT 'TRUNCATE events;';
SELECT 'TRUNCATE classess;';
SELECT 'TRUNCATE reminders;';
SELECT 'TRUNCATE userattrtypes;';
SELECT 'TRUNCATE users;';
SELECT 'TRUNCATE userattrs;';
SELECT 'TRUNCATE payments;';
SELECT 'TRUNCATE paymentattrs;';
SELECT 'TRUNCATE radacct;';


.mode insert config
SELECT 
    COALESCE((name), ''),
    COALESCE((value), '')
    FROM config;


.mode insert acctypes
SELECT 
    COALESCE(CAST((acctype_id) AS INT), 0),
    COALESCE((name), ''),
    COALESCE(CAST((class_id) AS INT), 0),
    COALESCE(CASE WHEN CAST((limit_duration) AS INT) = 1 THEN 1 ELSE 0 END, 0),
    COALESCE(CASE WHEN CAST((limit_mb) AS INT) = 1 THEN 1 ELSE 0 END, 0),
    COALESCE(CASE WHEN CAST((limit_interval) AS INT) = 1 THEN 1 ELSE 0 END, 0),
    COALESCE(CAST((max_sim_use) AS INT), 0),
    COALESCE((ip_pool), ''),
    COALESCE((radreply), ''),
    COALESCE((notes), ''),
    COALESCE(CAST(REPLACE(LOWER(default_price), 'o', '0') AS FLOAT), 0.00),
    COALESCE(CAST((default_mb_in) AS FLOAT), 0.0),
    COALESCE(CAST((default_mb_out) AS FLOAT), 0.0),
    COALESCE(CAST((default_mb_total) AS FLOAT), 0.0),
    COALESCE((default_interval), ''),
    COALESCE(CAST((default_hours) AS FLOAT), 0.0)
    FROM acctypes;


.mode insert zip
SELECT
COALESCE(CAST((zip_id) AS INT), 0),
COALESCE(string, '')
FROM zip_new;


.mode insert nas
SELECT 
    COALESCE(CAST((nas_id) AS INT), 0),
    COALESCE((type), ''),
    COALESCE((address), ''),
    COALESCE((nas_identifier), ''),
    COALESCE((secret), ''),
    COALESCE((snmp_community), ''),
    COALESCE(CAST((interim_update) AS INT), 0),
    COALESCE(CAST((max_sim_use) AS INT), 0),
    COALESCE((ip_pool), ''),
    COALESCE((radreply), ''),
    COALESCE((notes), ''),
    COALESCE((ifmaclist), '')
    FROM nas;


.mode insert events
SELECT 
    COALESCE(CAST((event_id) AS INT), 0),
    COALESCE(CAST((user_id) AS INT), 0),
    COALESCE(datetime(strftime('%s', (datetime(event_time, 'unixepoch'))), 'unixepoch'), '1970-01-01 00:00:00'),
    COALESCE((event_code), ''),
    COALESCE((params), '')
    FROM events;


.mode insert classess
SELECT 
    COALESCE(CAST((class_id) AS INT), 0),
    COALESCE((object), ''),
    COALESCE((name), '')
    FROM classess;


.mode insert reminders
SELECT 
    COALESCE(CAST((reminder_id) AS INT), 0),
    COALESCE(CAST((class_id) AS INT), 0),
    COALESCE(datetime(strftime('%s', (creation_time)), 'unixepoch'), '1970-01-01 00:00:00'),
    COALESCE(CAST((operator_id) AS INT), 0),
    COALESCE(CAST((user_id) AS INT), 0),
    COALESCE((description), '')
    FROM reminders;


.mode insert userattrtypes
SELECT 
    COALESCE(CAST((userattr_id) AS INT), 0),
    COALESCE((name), ''),
    COALESCE((type), ''),
    COALESCE(("values"), ''),
    COALESCE(("default"), ''),
    COALESCE(CASE WHEN CAST((required) AS INT) = 1 THEN 1 ELSE 0 END, 0),
    COALESCE(CASE WHEN CAST((user_visible) AS INT) = 1 THEN 1 ELSE 0 END, 0),
    COALESCE(CAST((position) AS INT), 0)
    FROM userattrtypes;


.mode insert users
SELECT 
    COALESCE(CAST((user_id) AS INT), 0),
    COALESCE((username), ''),
    COALESCE((plainpassword), ''),
    COALESCE(CAST((acctype_id) AS INT), 0),
    COALESCE(CAST((class_id) AS INT), 0),
    COALESCE(CAST((access_level) AS INT), 0),
    COALESCE(CAST((operator_id) AS INT), 0),
    COALESCE(datetime(strftime('%s', (activation_time)), 'unixepoch'), '1970-01-01 00:00:00'),
    COALESCE(datetime(strftime('%s', (creation_time)), 'unixepoch'), '1970-01-01 00:00:00'),
    COALESCE(CAST((max_sim_use) AS INT), 0),
    COALESCE((ip_pool), ''),
    COALESCE((radreply), ''),
    COALESCE(CAST((nas_id) AS INT), 0),
    COALESCE((notes), ''),
    COALESCE(CASE WHEN CAST((active) AS INT) = 1 THEN 1 ELSE 0 END, 0),
    datetime(strftime('%s', (status_expires)), 'unixepoch'),
    COALESCE(CAST((hours_used) AS FLOAT), 0.0),
    COALESCE(CAST((hours_limit) AS FLOAT), 0.0),
    COALESCE(CAST((mb_in_used) AS FLOAT), 0.0),
    COALESCE(CAST((mb_in_limit) AS FLOAT), 0.0),
    COALESCE(CAST((mb_out_used) AS FLOAT), 0.0),
    COALESCE(CAST((mb_out_limit) AS FLOAT), 0.0),
    COALESCE(CAST((mb_total_limit) AS FLOAT), 0.0),
    datetime(strftime('%s', (start)), 'unixepoch'),
    datetime(strftime('%s', (stop)), 'unixepoch'),
    datetime(strftime('%s', (last_auth)), 'unixepoch'),
    datetime(strftime('%s', (last_login)), 'unixepoch')
    FROM users;


.mode insert userattrs
SELECT 
    COALESCE(CAST((user_id) AS INT), 0),
    COALESCE(CAST((userattr_id) AS INT), 0),
    COALESCE((value), '')
    FROM userattrs;


.mode insert payments
SELECT 
    COALESCE(CAST((payment_id) AS INT), 0),
    COALESCE(CASE WHEN CAST((active) AS INT) = 1 THEN 1 ELSE 0 END, 0),
    COALESCE(CAST((user_id) AS INT), 0),
    COALESCE(CAST((class_id) AS INT), 0),
    COALESCE(CAST((acctype_id) AS INT), 0),
    COALESCE(CAST((hours) AS FLOAT), 0.0),
    COALESCE(CAST((mb_in) AS FLOAT), 0.0),
    COALESCE(CAST((mb_out) AS FLOAT), 0.0),
    COALESCE(CAST((mb_total) AS FLOAT), 0.0),
    datetime(strftime('%s', (start)), 'unixepoch'),
    datetime(strftime('%s', (stop)), 'unixepoch'),
    COALESCE(CAST(REPLACE(LOWER(price), 'o', '0') AS FLOAT), 0.00),
    COALESCE(CAST((operator_id) AS INT), 0),
    COALESCE(datetime(strftime('%s', (payment_date)), 'unixepoch'), '1970-01-01 00:00:00'),
    COALESCE((notes), ''),
    COALESCE(CASE WHEN CAST((charged) AS INT) = 1 THEN 1 ELSE 0 END, 0),
    COALESCE(datetime(strftime('%s', (charge_date)), 'unixepoch'), '1970-01-01 00:00:00')
    FROM payments;


.mode insert paymentattrs
SELECT 
    COALESCE(CAST((payment_id) AS INT), 0),
    COALESCE(CAST((paymentattr_id) AS INT), 0),
    COALESCE((value), '')
    FROM paymentattrs;




.mode insert radacct
SELECT 
    COALESCE(CAST((radacct_id) AS INT), 0),
    (NULL),
    COALESCE(CAST((user_id) AS INT), 0),
    COALESCE(CAST((start) AS INT), 0),
    COALESCE(CAST((duration) AS INT), 0),
    COALESCE(CAST((mb_in*1024.0*1024.0) AS INT), 0),
    COALESCE(CAST((mb_out*1024.0*1024.0) AS INT), 0),
    COALESCE(CAST((SELECT zip_id FROM zip_new WHERE string=(SELECT string FROM zip WHERE zip_id=nas_ip)) AS INT), 0),
    COALESCE(CAST((SELECT zip_id FROM zip_new WHERE string=(SELECT string FROM zip WHERE zip_id=framed_ip)) AS INT), 0),
    COALESCE(CAST((SELECT zip_id FROM zip_new WHERE string=(SELECT string FROM zip WHERE zip_id=calling_id)) AS INT), 0),
    COALESCE(CAST((SELECT zip_id FROM zip_new WHERE string=(SELECT string FROM zip WHERE zip_id=terminate_cause)) AS INT), 0)
    FROM radacct;



.mode tabs
SELECT 'SELECT setval(''radacct_radacct_id_seq'', ' || 
    ((SELECT COALESCE(seq, 0) FROM sqlite_sequence WHERE name='radacct') + 1) 
    || ', false);';
SELECT 'INSERT INTO config(name, value) VALUES (''db_rev'', 1);';
SELECT 'COMMIT;';


.output 'archive_dump.sql'

attach 'archive.db' as arch;

.mode insert radacct
SELECT 
    COALESCE(CAST((radacct_id) AS INT), 0),
    (NULL),
    COALESCE(CAST((user_id) AS INT), 0),
    COALESCE(CAST((start) AS INT), 0),
    COALESCE(CAST((duration) AS INT), 0),
    COALESCE(CAST((mb_in*1024.0*1024.0) AS INT), 0),
    COALESCE(CAST((mb_out*1024.0*1024.0) AS INT), 0),
    COALESCE(CAST((SELECT zip_id FROM zip_new WHERE string=(SELECT string FROM zip WHERE zip_id=nas_ip)) AS INT), 0),
    COALESCE(CAST((SELECT zip_id FROM zip_new WHERE string=(SELECT string FROM zip WHERE zip_id=framed_ip)) AS INT), 0),
    COALESCE(CAST((SELECT zip_id FROM zip_new WHERE string=(SELECT string FROM zip WHERE zip_id=calling_id)) AS INT), 0),
    COALESCE(CAST((SELECT zip_id FROM zip_new WHERE string=(SELECT string FROM zip WHERE zip_id=terminate_cause)) AS INT), 0)
    FROM arch.radacct;


.quit
