DROP TABLE IF EXISTS nas;
CREATE TABLE nas (
    nas_id SERIAL PRIMARY KEY,
    type TEXT NOT NULL DEFAULT '',
    address INET UNIQUE NOT NULL DEFAULT '0.0.0.0',
    nas_identifier TEXT UNIQUE NOT NULL DEFAULT '',
    secret TEXT NOT NULL DEFAULT '',
    snmp_community TEXT NOT NULL DEFAULT '',
    interim_update INTEGER NOT NULL DEFAULT 0,
    max_sim_use INTEGER NOT NULL DEFAULT -1,
    ip_pool TEXT NOT NULL DEFAULT '',
    radreply TEXT NOT NULL DEFAULT '',
    notes TEXT NOT NULL DEFAULT '',
    ifmaclist TEXT NOT NULL DEFAULT ''
);


DROP TABLE IF EXISTS radiuslog;
CREATE TABLE radiuslog (
    radiuslog_id BIGSERIAL PRIMARY KEY,
    event_time BIGINT NOT NULL DEFAULT 0,
    nas_ip INTEGER NOT NULL DEFAULT 0,
    username INTEGER NOT NULL DEFAULT 0,
    accept SMALLINT NOT NULL DEFAULT 0 CHECK(accept IN (0, 1)),
    event_code INTEGER NOT NULL DEFAULT 0,
    calling_id INTEGER NOT NULL DEFAULT 0,
    framed_ip INTEGER NOT NULL DEFAULT 0
);


DROP TABLE IF EXISTS events;
CREATE TABLE events (
    event_id SERIAL PRIMARY KEY,
    user_id INTEGER NOT NULL DEFAULT 0,
    event_time TIMESTAMP(0) NOT NULL DEFAULT CURRENT_TIMESTAMP::TIMESTAMP(0) WITHOUT TIME ZONE,
    event_code TEXT NOT NULL DEFAULT '',
    params TEXT NOT NULL DEFAULT ''
);


DROP TABLE IF EXISTS classess;
CREATE TABLE classess (
    class_id INTEGER NOT NULL DEFAULT 0,
    object TEXT NOT NULL DEFAULT '',
    name TEXT NOT NULL DEFAULT '',
    UNIQUE (class_id, object),
    UNIQUE (object, name)
);


DROP TABLE IF EXISTS reminders;
CREATE TABLE reminders (
    reminder_id SERIAL PRIMARY KEY,
    class_id INTEGER NOT NULL DEFAULT 0,
    creation_time TIMESTAMP(0) NOT NULL DEFAULT CURRENT_TIMESTAMP::TIMESTAMP(0) WITHOUT TIME ZONE,
    operator_id INTEGER NOT NULL DEFAULT 0,
    user_id INTEGER NOT NULL DEFAULT 0,
    description TEXT NOT NULL DEFAULT ''
);


DROP TABLE IF EXISTS userattrtypes;
CREATE TABLE userattrtypes (
    userattr_id SERIAL PRIMARY KEY,
    name TEXT UNIQUE NOT NULL DEFAULT '',
    type TEXT NOT NULL DEFAULT '',
    value_list TEXT NOT NULL DEFAULT '',
    default_value TEXT NOT NULL DEFAULT '',
    required SMALLINT NOT NULL DEFAULT 0 CHECK(required IN (0, 1)),
    user_visible SMALLINT NOT NULL DEFAULT 0 CHECK(user_visible IN (0, 1)),
    position INTEGER NOT NULL DEFAULT 0
);


DROP TABLE IF EXISTS sessions;
CREATE TABLE sessions (
    session_id TEXT PRIMARY KEY,
    user_id INTEGER NOT NULL DEFAULT 0,
    start TIMESTAMP(0) NOT NULL DEFAULT CURRENT_TIMESTAMP::TIMESTAMP(0) WITHOUT TIME ZONE,
    last_action TIMESTAMP(0) NOT NULL DEFAULT CURRENT_TIMESTAMP::TIMESTAMP(0) WITHOUT TIME ZONE,
    admin_portal SMALLINT NOT NULL DEFAULT 0 CHECK(admin_portal IN (0, 1)),
    address INET NOT NULL DEFAULT '0.0.0.0',
    user_agent TEXT NOT NULL DEFAULT '',
    vars TEXT NOT NULL DEFAULT ''
);


DROP TABLE IF EXISTS users;
CREATE TABLE users (
    user_id SERIAL PRIMARY KEY,
    username TEXT UNIQUE NOT NULL DEFAULT '',
    password TEXT NOT NULL DEFAULT '',
    acctype_id INTEGER NOT NULL DEFAULT 0,
    class_id INTEGER NOT NULL DEFAULT 0,
    access_level INTEGER NOT NULL DEFAULT 0,
    operator_id INTEGER NOT NULL DEFAULT 0,
    activation_time TIMESTAMP(0) NOT NULL DEFAULT CURRENT_TIMESTAMP::TIMESTAMP(0) WITHOUT TIME ZONE,
    creation_time TIMESTAMP(0) NOT NULL DEFAULT CURRENT_TIMESTAMP::TIMESTAMP(0) WITHOUT TIME ZONE,
    max_sim_use INTEGER NOT NULL DEFAULT -1,
    ip_pool TEXT NOT NULL DEFAULT '',
    radreply TEXT NOT NULL DEFAULT '',
    nas_id INTEGER NOT NULL DEFAULT 0,
    notes TEXT NOT NULL DEFAULT '',
    active SMALLINT NOT NULL DEFAULT 0 CHECK(active IN (0, 1)),
    status_expires TIMESTAMP(0),
    hours_used REAL NOT NULL DEFAULT 0.0,
    hours_limit REAL NOT NULL DEFAULT 0.0,
    mb_in_used REAL NOT NULL DEFAULT 0.0,
    mb_in_limit REAL NOT NULL DEFAULT 0.0,
    mb_out_used REAL NOT NULL DEFAULT 0.0,
    mb_out_limit REAL NOT NULL DEFAULT 0.0,
    mb_total_limit REAL NOT NULL DEFAULT 0.0,
    start TIMESTAMP(0),
    stop TIMESTAMP(0),
    last_auth TIMESTAMP(0),
    last_login TIMESTAMP(0)
);


DROP TABLE IF EXISTS userattrs;
CREATE TABLE userattrs (
    user_id INTEGER NOT NULL DEFAULT 0,
    userattr_id INTEGER NOT NULL DEFAULT 0,
    value TEXT NOT NULL DEFAULT '',
    PRIMARY KEY (user_id, userattr_id)
);


DROP TABLE IF EXISTS payments;
CREATE TABLE payments (
    payment_id SERIAL PRIMARY KEY,
    active SMALLINT NOT NULL DEFAULT 0 CHECK(active IN (0, 1)),
    user_id INTEGER NOT NULL DEFAULT 0,
    class_id INTEGER NOT NULL DEFAULT 0,
    acctype_id INTEGER NOT NULL DEFAULT 0,
    hours REAL NOT NULL DEFAULT 0.0,
    mb_in REAL NOT NULL DEFAULT 0.0,
    mb_out REAL NOT NULL DEFAULT 0.0,
    mb_total REAL NOT NULL DEFAULT 0.0,
    start TIMESTAMP(0),
    stop TIMESTAMP(0),
    price NUMERIC(12,2) NOT NULL DEFAULT 0.00,
    operator_id INTEGER NOT NULL DEFAULT 0,
    payment_date TIMESTAMP(0) NOT NULL DEFAULT CURRENT_TIMESTAMP::TIMESTAMP(0) WITHOUT TIME ZONE,
    notes TEXT NOT NULL DEFAULT '',
    charged SMALLINT NOT NULL DEFAULT 0 CHECK(charged IN (0, 1)),
    charge_date TIMESTAMP(0) NOT NULL DEFAULT CURRENT_TIMESTAMP::TIMESTAMP(0) WITHOUT TIME ZONE
);


DROP TABLE IF EXISTS paymentattrs;
CREATE TABLE paymentattrs (
    payment_id INTEGER NOT NULL DEFAULT 0,
    paymentattr_id INTEGER NOT NULL DEFAULT 0,
    value TEXT NOT NULL DEFAULT '',
    PRIMARY KEY (payment_id, paymentattr_id)
);


DROP TABLE IF EXISTS radacct;
CREATE TABLE radacct (
    radacct_id BIGSERIAL PRIMARY KEY,
    session_id TEXT UNIQUE,
    user_id INTEGER NOT NULL DEFAULT 0,
    start BIGINT NOT NULL DEFAULT 0,
    duration INTEGER NOT NULL DEFAULT 0,
    octets_in BIGINT NOT NULL DEFAULT 0,
    octets_out BIGINT NOT NULL DEFAULT 0,
    nas_ip INTEGER NOT NULL DEFAULT 0,
    framed_ip INTEGER NOT NULL DEFAULT 0,
    calling_id INTEGER NOT NULL DEFAULT 0,
    terminate_cause INTEGER NOT NULL DEFAULT 0
);
CREATE INDEX radacct_user_id ON radacct (user_id);
CREATE INDEX radacct_start ON radacct (start);

DROP TABLE IF EXISTS radacctattrs;
CREATE TABLE radacctattrs (
    radacct_id INTEGER NOT NULL DEFAULT 0,
    radacctattr_id INTEGER NOT NULL DEFAULT 0,
    value TEXT NOT NULL DEFAULT '',
    PRIMARY KEY (radacct_id, radacctattr_id)
);


DROP TABLE IF EXISTS signals;
CREATE TABLE signals (
    nas_id INTEGER NOT NULL DEFAULT 0,
    mac_address MACADDR NOT NULL DEFAULT '000000000000',
    strength INTEGER NOT NULL DEFAULT 0,
    user_id INTEGER NOT NULL DEFAULT 0,
    if_name TEXT NOT NULL DEFAULT '',
    PRIMARY KEY (nas_id, mac_address)
);


DROP TABLE IF EXISTS online;
CREATE TABLE online (
    online_id TEXT PRIMARY KEY,
    username TEXT NOT NULL DEFAULT '',
    start TIMESTAMP(0) NOT NULL,
    duration INTEGER NOT NULL DEFAULT 0,
    octets_in BIGINT NOT NULL DEFAULT 0,
    octets_out BIGINT NOT NULL DEFAULT 0,
    nas_ip INET NOT NULL DEFAULT '0.0.0.0',
    nas_port TEXT NOT NULL DEFAULT '',
    calling_id TEXT NOT NULL DEFAULT '',
    called_id TEXT NOT NULL DEFAULT '',
    terminate_cause TEXT NOT NULL DEFAULT '',
    framed_ip INET NOT NULL DEFAULT '0.0.0.0',
    last_update BIGINT NOT NULL DEFAULT 0,
    account_alive SMALLINT NOT NULL DEFAULT 0 CHECK(account_alive IN (0, 1))
);
CREATE INDEX online_username ON online (username);

DROP TABLE IF EXISTS zip;
CREATE TABLE zip (
    zip_id SERIAL PRIMARY KEY,
    string TEXT NOT NULL DEFAULT ''
);


DROP TABLE IF EXISTS mail;
CREATE TABLE mail (
    mail_id SERIAL PRIMARY KEY,
    sender TEXT NOT NULL DEFAULT '',
    recipient TEXT NOT NULL DEFAULT '',
    subject TEXT NOT NULL DEFAULT '',
    body TEXT NOT NULL DEFAULT '',
    mime TEXT NOT NULL DEFAULT '',
    expires TIMESTAMP(0) NOT NULL,
    last_attempt TIMESTAMP(0)
);


DROP TABLE IF EXISTS config;
CREATE TABLE config (
    name TEXT PRIMARY KEY,
    value TEXT NOT NULL DEFAULT ''
);


DROP TABLE IF EXISTS acctypes;
CREATE TABLE acctypes (
    acctype_id SERIAL PRIMARY KEY,
    name TEXT UNIQUE NOT NULL DEFAULT '',
    class_id INTEGER NOT NULL DEFAULT 0,
    limit_duration SMALLINT NOT NULL DEFAULT 0 CHECK(limit_duration IN (0, 1)),
    limit_mb SMALLINT NOT NULL DEFAULT 0 CHECK(limit_mb IN (0, 1)),
    limit_interval SMALLINT NOT NULL DEFAULT 0 CHECK(limit_interval IN (0, 1)),
    max_sim_use INTEGER NOT NULL DEFAULT -1,
    ip_pool TEXT NOT NULL DEFAULT '',
    radreply TEXT NOT NULL DEFAULT '',
    notes TEXT NOT NULL DEFAULT '',
    default_price NUMERIC(12,2) NOT NULL DEFAULT 0.00,
    default_mb_in REAL NOT NULL DEFAULT 0.0,
    default_mb_out REAL NOT NULL DEFAULT 0.0,
    default_mb_total REAL NOT NULL DEFAULT 0.0,
    default_interval TEXT NOT NULL DEFAULT '',
    default_hours REAL NOT NULL DEFAULT 0.0
);



INSERT INTO users (username, password, access_level) VALUES ('admin', 'admin', 5);

INSERT INTO nas (address, nas_identifier, secret) VALUES ('127.0.0.1', 'localhost', 'secret');

INSERT INTO userattrtypes (name, type) VALUES ('Name', 'text');
INSERT INTO userattrtypes (name, type) VALUES ('Address', 'text');
INSERT INTO userattrtypes (name, type) VALUES ('City', 'text');
INSERT INTO userattrtypes (name, type) VALUES ('City code', 'int');
INSERT INTO userattrtypes (name, type, value_list) VALUES ('Date of birth', 'date', '-18, -90');
INSERT INTO userattrtypes (name, type, default_value) VALUES ('Is WiFi user', 'bool', '0');
INSERT INTO userattrtypes (name, type, value_list, default_value) VALUES ('Support level', 'select', 'none, basic, premium', 'none');
INSERT INTO userattrtypes (name, type) VALUES ('Technical notes', 'textarea');

INSERT INTO acctypes (name) VALUES ('Always active');
INSERT INTO acctypes (name, limit_duration) VALUES ('Prepaid hours', 1);
INSERT INTO acctypes (name, limit_mb) VALUES ('Prepaid MB', 1);
INSERT INTO acctypes (name, limit_interval, default_interval) VALUES ('Flatrate', 1, '1 month');
INSERT INTO acctypes (name, limit_interval, limit_mb, default_interval) VALUES ('Flatrate + MB limit', 1, 1, '1 month');
INSERT INTO acctypes (name, limit_interval, limit_duration, default_interval) VALUES ('Flatrate + hourly limit', 1, 1, '1 month');

INSERT INTO classess VALUES (1, 'user', 'private');
INSERT INTO classess VALUES (2, 'user', 'virtual');
INSERT INTO classess VALUES (3, 'user', 'bussiness');
INSERT INTO classess VALUES (4, 'user', 'reserved username');
INSERT INTO classess VALUES (1, 'payment', 'cash');
INSERT INTO classess VALUES (2, 'payment', 'check');
INSERT INTO classess VALUES (3, 'payment', 'gratis');
INSERT INTO classess VALUES (1, 'reminder', 'support request (opened)');
INSERT INTO classess VALUES (1000, 'reminder', 'support request (closed)');
