/**
 ================== Utility functions.  ==================
*/

// trims whitespaces 
function trim(str) {
    return ltrim(rtrim(str));
}

function ltrim(str) {
    var chars = "\\t\\n\\s";
    return str.replace(new RegExp("^[" + chars + "]+", "g"), "");
}

function rtrim(str) {
    var chars = "\\t\\n\\s";
    return str.replace(new RegExp("[" + chars + "]+$", "g"), "");
}

// gets element by id
function get(id){
	return document.getElementById(id)
}

// gets element by name
function getbyname(name){
	return document.getElementsByName(name)
}


// returns selected item value from option list
function getselected(id){
	var e = get(id)
	if (e == undefined)
		return ''
	else
		return e.options[e.selectedIndex].value
}

/**
 ================== Menu handling functions.  ==================
*/

// shows linkgroup idx and hide other groups
function showlinkgroup(idx, linkgroup_count){
	for(var i=0; i<linkgroup_count+1; i++){
		var e = document.getElementById('linkgroup_'+i)
		var b = document.getElementById('linkgroup_'+i+'_mainbutton')
		if (e) e.style.display = (i == idx) ? '' : 'none';
		if (b) b.disabled = i == idx;
	}
}

/**
 ================== Form handling functions.  ==================
*/

/**
 Used with Form tabs.
 Shows tab acording to its itd. 
*/
function showtab(form_name, tab_id, tab_count, item_count) {
	// first loop trough all items (input rows in form)
	for (var i=0; i<item_count; i++){
		var e = document.getElementById( form_name + '_item_' + i )
		if (e)
			e.style.display = (e.getAttribute('tab_id') == tab_id || e.getAttribute('tab_id') == 0) ? '' : 'none'
	}

	// loop and disable/enable tab buttons
	for (var i=1; i<tab_count; i++){
		var e = document.getElementById(form_name + '_tabbutton_' + i)
			if (e)
				e.disabled = (i == tab_id) ? 1 : 0;
	}
}

/**
 Checks/unchecks column of checkboxes by clicking on header.
 All checkboxes must have same name.
*/
function toggle_column(name, checked){
	var items = document.getElementsByName(name);
	for (var i=0; i<items.length; i++){
		if (items[i].type == "checkbox")
			items[i].checked = checked
	}
}


/**
 ================== Time displaying functions.  ==================
*/

// dinamically loaded from script
var dateformat = ""
var months = ""

// globals
var tstamp = 0	// total number of seconds since 1970-01-01 00:00:00
var tagid = ""	// element id which innerHTML will be used as clock display

/*
 Starts clock. 
 Id is the id of <SPAN> or other element with .innerHTML to use as display.
 Timestamp is the number of seconds since Big moment.
*/
function startclock(id, timestamp){
	tagid = id
	tstamp = timestamp
	showtime()
}

// zero filled with 2 digits
function zf2(i) {
	if (i < 0)		return "-"
	else if (i > 9)	return "" + i
	else		return "0" + i
}

// zero filled with 4 digits
function zf4(i) {
	if (i < 0)			return "-"
	else if (i > 999)	return "" + i
	else if (i > 99)	return "0" + i
	else if (i > 9)		return "00" + i
	else			return "000" + i
}

function showtime() {
	date = new Date(tstamp * 1000)
	var y = zf4(date.getUTCFullYear())
	var m = zf2(date.getUTCMonth() + 1)
	var d = zf2(date.getUTCDate())
	var t = zf2(date.getUTCHours()) + ':' + zf2(date.getUTCMinutes()) + ':' + zf2(date.getUTCSeconds())
	var s = ""
	
	if (dateformat == "MM/DD/YYYY")
		s = m+"/"+d+"/"+y
	else if (dateformat == "DD.MM.YYYY.")
		s = d+"."+m+"."+y+"."
	else if (dateformat == "DD. mmm YYYY.")
		s = d+". "+months.split(",")[date.getUTCMonth()]+" "+y+"."
	else
		s = y+"-"+m+"-"+d
	
	document.getElementById(tagid).innerHTML = s + " " + t

	tstamp++
	setTimeout('showtime()',1000)
}


/**
=============== Check form input fields before submiting/after changing ==================
*/

/**
Checks all input form fields if they are in correct format and enables/disables form submit.
Returns true if form is valid for submit or false if some input is wrong.
 
Posibilities for input field:
 if it has required=yes attribute then it must have non-whitespace value
For butons:
 if it has always_enabled=yes then it wont be disabled when form is disabled
 
Note: if not enabled do not put required=no or always_enabled=no becouse it will confuse Opera etc.
*/
function checkform(form){
	var form_ok = true;
	// check input fields
	for (i = 0; i < form.length; i++) {
		var e = form.elements[i];
		var type = e.type.toLowerCase();
		var required = false;
		// works on IE and Firefox
		if (e.getAttribute('required') != undefined && e.getAttribute('required').toLowerCase() == "yes")
			required = true
		// Opera bug, for some strange reason it sucks on many levels more than IE
		if (e.getAttribute('required') != undefined && e.getAttribute('required').toLowerCase() == "required")
			required = true
		var empty = trim(e.value) == ""

		//alert(e.getAttribute('required') + ' ' + e['required'] + ' ' + e.required + ' ' + empty)
		if (type == "select-one"){
			empty = trim(e.options[e.selectedIndex].value) == ""
		}
		

		if (type == "text" || type == "password" || type == "textarea" || type == "select-one"){
				if (required && empty){
					form_ok = false;
					e.style.background="#FF3300";
				}
				else{
					e.style.background="white";
				}
		}
	}
	
	// submit buttons (this check is done on form.submit so there is no fear form wil be submited by hack)
	for (i = 0; i < form.length; i++) {
		var e = form.elements[i];
		var type = e.type.toLowerCase();
		var always_enabled = false;
		// same as above
		if (e.getAttribute('always_enabled') != undefined && e.getAttribute('always_enabled').toLowerCase() == "yes")
			always_enabled = true
		if (e.getAttribute('always_enabled') != undefined && e.getAttribute('always_enabled').toLowerCase() == "always_enabled")
			always_enabled = true
		
		if ( type == "submit" || type == "reset" || type == "button" ){
			if (always_enabled)
				e.disabled = e.disabled // keep the state, this might be the tab button or such
			else
				e.disabled = !form_ok
		}
	}
	
	return form_ok;
}


/**
=============== Password generator  ==================
*/

function _randNum(start, stop) {
	return (Math.floor(Math.random() * (stop - start)) + start);
}

function _randChar() {
	var c = "abcdefghijkmnpqrstuvwxyz";
	return c.charAt(_randNum(0, c.length));
}
function _randDigit() {
	var c = "23456789";
	return c.charAt(_randNum(0, c.length));
}


function getRandomPassword(){
	var pass = '';
	for(i=0; i < 8; i++)
		pass = _randChar();
	return _randChar() + _randDigit() + _randChar() + _randDigit() + _randChar() + _randDigit() + _randChar() + _randDigit();
}
